@@ -9,7 +9,7 @@
 */
 
 /* ====================================================================
- * Copyright (c) 1998 Ralf S. Engelschall. All rights reserved.
+ * Copyright (c) 1998-1999 Ralf S. Engelschall. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -185,9 +185,6 @@
  * Defaults for the configuration
  */
 
-#ifndef SSL_CERTIFCATE_FILE
-#define SSL_CERTIFCATE_FILE        "conf/ssl.crt/server.crt"
-#endif
 #ifndef SSL_SESSION_CACHE_TIMEOUT
 #define SSL_SESSION_CACHE_TIMEOUT  300
 #endif
