@@ -9,7 +9,7 @@
 */
 
 /* ====================================================================
- * Copyright (c) 1998 Ralf S. Engelschall. All rights reserved.
+ * Copyright (c) 1998-1999 Ralf S. Engelschall. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -144,7 +144,7 @@ void *ssl_config_server_create(pool *p, server_rec *s)
 
     sc = ap_palloc(p, sizeof(SSLSrvConfigRec));
     sc->bEnabled               = UNSET;
-    sc->szCertificateFile      = SSL_CERTIFCATE_FILE;
+    sc->szCertificateFile      = NULL;
     sc->szKeyFile              = NULL;
     sc->szCACertificatePath    = NULL;
     sc->szCACertificateFile    = NULL;
@@ -295,9 +295,9 @@ const char *ssl_cmd_SSLPassPhraseDialog(
         sc->nPassPhraseDialogType  = SSL_PPTYPE_BUILTIN;
         sc->szPassPhraseDialogPath = NULL;
     }
-    else if (strlen(arg) > 2 && arg[0] == '/') {
+    else if (strlen(arg) > 5 && strEQn(arg, "exec:", 5)) {
         sc->nPassPhraseDialogType  = SSL_PPTYPE_FILTER;
-        sc->szPassPhraseDialogPath = ap_server_root_relative(cmd->pool, arg);
+        sc->szPassPhraseDialogPath = ap_server_root_relative(cmd->pool, arg+5);
         if (!ssl_util_path_check(SSL_PCM_EXISTS, sc->szPassPhraseDialogPath))
             return ap_pstrcat(cmd->pool, "SSLPassPhraseDialog: file '",
                               sc->szPassPhraseDialogPath, "' not exists", NULL);
