@@ -9,7 +9,7 @@
 */
 
 /* ====================================================================
- * Copyright (c) 1998 Ralf S. Engelschall. All rights reserved.
+ * Copyright (c) 1998-1999 Ralf S. Engelschall. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -60,7 +60,7 @@
  */
 
 /* ====================================================================
- * Copyright (c) 1995, 1996, 1997, 1998 Ben Laurie.  All rights reserved.
+ * Copyright (c) 1995-1999 Ben Laurie. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -271,14 +271,7 @@ void ssl_init_Module(server_rec *s, pool *p)
          * Now check for important parameters and the
          * possibility that the user forgot to set them.
          */
-        if (sc->nSessionCacheTimeout == 0) {
-            ssl_log(s, SSL_LOG_ERROR,
-                    "Init: (%s:%d) No SSL Session Cache Timeout set "
-                    "[hint: SSLSessionCacheTimeout]",
-                    s->server_hostname, s->port);
-            ssl_die();
-        }
-        if (!sc->szCertificateFile) {
+        if (sc->szCertificateFile == NULL) {
             ssl_log(s, SSL_LOG_ERROR,
                     "Init: (%s:%d) No SSL Certificate set [hint: SSLCertificateFile]",
                     s->server_hostname, s->port);
